@@ -102,6 +102,7 @@ class OSSFileSystem(
             like: http://oss-cn-hangzhou.aliyuncs.com or
                         https://oss-me-east-1.aliyuncs.com
         """
+        super().__init__(**kwargs)
         if token:
             self._auth = oss2.StsAuth(key, secret, token)
         elif key:
@@ -110,7 +111,22 @@ class OSSFileSystem(
             self._auth = oss2.AnonymousAuth()
         self._endpoint = endpoint
         self._default_cache_type = default_cache_type
-        super().__init__(**kwargs)
+        self._session = oss2.Session()
+
+    def _get_bucket(
+        self, bucket_name: str, connect_timeout: Optional[int] = None
+    ):
+        """
+        get the new bucket instance
+        """
+        return oss2.Bucket(
+            self._auth,
+            self._endpoint,
+            bucket_name,
+            session=self._session,
+            connect_timeout=connect_timeout,
+            app_name="ossfs",
+        )
 
     def split_path(self, path: str) -> Tuple[str, str]:
         """
@@ -228,12 +244,7 @@ class OSSFileSystem(
 
     def _ls_object(self, path: str, connect_timeout) -> List[Dict]:
         bucket_name, obj_name = self.split_path(path)
-        bucket = oss2.Bucket(
-            self._auth,
-            self._endpoint,
-            bucket_name,
-            connect_timeout=connect_timeout,
-        )
+        bucket = self._get_bucket(bucket_name, connect_timeout)
         infos = []
         if not self._object_exists(bucket, obj_name):
             return infos
@@ -257,36 +268,25 @@ class OSSFileSystem(
 
         return infos
 
-    def _ls_directory(
+    def _get_object_info_list(
         self,
-        path: str,
-        delimiter: str = "/",
-        prefix: Optional[str] = None,
-        connect_timeout: int = None,
-    ) -> List[Dict]:
-        path = path.rstrip("/") + "/"
-        bucket_name, directory = self.split_path(path)
-        bucket = oss2.Bucket(
-            self._auth,
-            self._endpoint,
-            bucket_name,
-            connect_timeout=connect_timeout,
-        )
+        bucket_name: str,
+        prefix: str,
+        delimiter: str,
+        connect_timeout: int,
+    ):
+        """
+        Wrap oss2.ObjectIterator return values into a
+        fsspec form of file info
+        """
+        bucket = self._get_bucket(bucket_name, connect_timeout)
         infos = []
-        bucket_path = (
-            f"/{bucket_name}/" if path.startswith("/") else f"{bucket_name}/"
-        )
-        prefix = (
-            directory
-            if not prefix
-            else "/".join([directory.rstrip("/"), prefix])
-        )
         for obj in oss2.ObjectIterator(
             bucket, prefix=prefix, delimiter=delimiter
         ):
             data = {
-                "name": bucket_path + obj.key,
-                "Key": bucket_path + obj.key,
+                "name": f"{bucket_name}/{obj.key}",
+                "Key": f"{bucket_name}/{obj.key}",
                 "type": "file",
                 "size": obj.size,
                 "Size": obj.size,
@@ -301,15 +301,43 @@ class OSSFileSystem(
             infos.append(data)
         return infos
 
+    def _ls_dir(
+        self,
+        path: str,
+        delimiter: str = "/",
+        prefix: Optional[str] = None,
+        connect_timeout: int = None,
+    ) -> List[Dict]:
+        norm_path = path.strip("/")
+        bucket_name, key = self.split_path(norm_path)
+        if not prefix:
+            prefix = ""
+        if key:
+            prefix = f"{key}/{prefix}"
+
+        if not delimiter or prefix:
+            infos = self._get_object_info_list(
+                bucket_name, prefix, delimiter, connect_timeout
+            )
+        else:
+            if norm_path not in self.dircache:
+                self.dircache[norm_path] = self._get_object_info_list(
+                    bucket_name, prefix, delimiter, connect_timeout
+                )
+            infos = self.dircache[norm_path]
+        if path.startswith("/"):
+            for info in infos:
+                info["name"] = f'/{info["name"]}'
+                info["Key"] = f'/{info["Key"]}'
+        return infos
+
     def ls(self, path, detail=True, **kwargs):
         connect_timeout = kwargs.pop("connect_timeout", 60)
         bucket_name, _ = self.split_path(path)
         if bucket_name:
             infos = self._ls_object(path, connect_timeout)
             if not infos:
-                infos = self._ls_directory(
-                    path, connect_timeout=connect_timeout
-                )
+                infos = self._ls_dir(path, connect_timeout=connect_timeout)
         else:
             infos = self._ls_bucket(connect_timeout)
 
@@ -345,7 +373,7 @@ class OSSFileSystem(
             )
         if prefix:
             connect_timeout = kwargs.get("connect_timeout", None)
-            for info in self._ls_directory(
+            for info in self._ls_dir(
                 path,
                 delimiter="",
                 prefix=prefix,
@@ -383,16 +411,11 @@ class OSSFileSystem(
     def _object_exists(bucket: oss2.Bucket, object_name: str):
         if not object_name:
             return False
-        try:
-            return bucket.object_exists(object_name)
-        except oss2.exceptions.ServerError:
-            return False
+        return bucket.object_exists(object_name)
 
     def _directory_exists(self, dirname: str, **kwargs):
         connect_timeout = kwargs.pop("connect_timeout", None)
-        ls_result = self._ls_directory(
-            dirname, connect_timeout=connect_timeout
-        )
+        ls_result = self._ls_dir(dirname, connect_timeout=connect_timeout)
         return bool(ls_result)
 
     def exists(self, path, **kwargs):
@@ -402,12 +425,7 @@ class OSSFileSystem(
             return False
 
         connect_timeout = kwargs.get("connect_timeout", None)
-        bucket = oss2.Bucket(
-            self._auth,
-            self._endpoint,
-            bucket_name,
-            connect_timeout=connect_timeout,
-        )
+        bucket = self._get_bucket(bucket_name, connect_timeout)
         if not self._bucket_exist(bucket):
             return False
 
@@ -423,7 +441,7 @@ class OSSFileSystem(
     def ukey(self, path):
         """Hash of file properties, to tell if it has changed"""
         bucket_name, obj_name = self.split_path(path)
-        bucket = oss2.Bucket(self._auth, self._endpoint, bucket_name)
+        bucket = self._get_bucket(bucket_name)
         obj_stream = bucket.get_object(obj_name)
         return obj_stream.server_crc
 
@@ -456,13 +474,9 @@ class OSSFileSystem(
             os.remove(tempdir)
         else:
             connect_timeout = kwargs.pop("connect_timeout", None)
-            bucket = oss2.Bucket(
-                self._auth,
-                self._endpoint,
-                bucket_name1,
-                connect_timeout=connect_timeout,
-            )
+            bucket = self._get_bucket(bucket_name1, connect_timeout)
             bucket.copy_object(bucket_name1, obj_name1, obj_name2)
+        self.invalidate_cache(self._parent(path2))
 
     @error_decorator
     def _rm(self, path: Union[str, List[str]]):
@@ -478,8 +492,9 @@ class OSSFileSystem(
                 self._rm(file)
             return
         bucket_name, obj_name = self.split_path(path)
-        bucket = oss2.Bucket(self._auth, self._endpoint, bucket_name)
+        bucket = self._get_bucket(bucket_name)
         bucket.delete_object(obj_name)
+        self.invalidate_cache(self._parent(path))
 
     @error_decorator
     def rm(self, path, recursive=False, maxdepth=None):
@@ -504,17 +519,21 @@ class OSSFileSystem(
             return
 
         bucket_name, _ = self.split_path(path)
-        bucket = oss2.Bucket(self._auth, self._endpoint, bucket_name)
-        path = self.expand_path(path, recursive=recursive, maxdepth=maxdepth)
-        path = [self.split_path(file)[1] for file in path]
+        bucket = self._get_bucket(bucket_name)
+        path_expand = self.expand_path(
+            path, recursive=recursive, maxdepth=maxdepth
+        )
+        path_expand = [self.split_path(file)[1] for file in path_expand]
 
         def chunks(lst: list, num: int):
             for i in range(0, len(lst), num):
                 yield lst[i : i + num]
 
-        for files in chunks(path, 1000):
+        for files in chunks(path_expand, 1000):
             bucket.batch_delete_objects(files)
 
+        self.invalidate_cache(self._parent(path))
+
     def get_path(self, rpath, lpath, **kwargs):
         """
         Copy single remote path to local
@@ -533,14 +552,8 @@ class OSSFileSystem(
         else:
             bucket_name, obj_name = self.split_path(rpath)
             connect_timeout = kwargs.pop("connect_timeout", None)
-            resumable = kwargs.pop("resumable", False)
-            bucket = oss2.Bucket(
-                self._auth,
-                self._endpoint,
-                bucket_name,
-                connect_timeout=connect_timeout,
-            )
-            if resumable:
+            bucket = self._get_bucket(bucket_name, connect_timeout)
+            if self.size(rpath) >= self.SIMPLE_TRANSFER_THRESHOLD:
                 oss2.resumable_download(bucket, obj_name, lpath, **kwargs)
             else:
                 bucket.get_object_to_file(obj_name, lpath, **kwargs)
@@ -572,17 +585,12 @@ class OSSFileSystem(
         else:
             bucket_name, obj_name = self.split_path(rpath)
             connect_timeout = kwargs.pop("connect_timeout", None)
-            bucket = oss2.Bucket(
-                self._auth,
-                self._endpoint,
-                bucket_name,
-                connect_timeout=connect_timeout,
-            )
-
+            bucket = self._get_bucket(bucket_name, connect_timeout)
             if os.path.getsize(lpath) >= self.SIMPLE_TRANSFER_THRESHOLD:
                 oss2.resumable_upload(bucket, obj_name, lpath, **kwargs)
             else:
                 bucket.put_object_from_file(obj_name, lpath, **kwargs)
+        self.invalidate_cache(self._parent(rpath))
 
     @error_decorator
     def created(self, path):
@@ -590,7 +598,7 @@ class OSSFileSystem(
         bucket_name, obj_name = self.split_path(path)
         if obj_name:
             raise NotImplementedError("OSS has no created timestamp")
-        bucket = oss2.Bucket(self._auth, self._endpoint, bucket_name)
+        bucket = self._get_bucket(bucket_name)
         timestamp = bucket.get_bucket_info().creation_date
         return datetime.fromtimestamp(timestamp)
 
@@ -600,7 +608,7 @@ class OSSFileSystem(
         bucket_name, obj_name = self.split_path(path)
         if not obj_name or self.isdir(path):
             raise NotImplementedError("bucket has no modified timestamp")
-        bucket = oss2.Bucket(self._auth, self._endpoint, bucket_name)
+        bucket = self._get_bucket(bucket_name)
         simplifiedmeta = bucket.get_object_meta(obj_name)
         return int(
             datetime.strptime(
@@ -615,7 +623,7 @@ class OSSFileSystem(
         Append bytes to the object
         """
         bucket_name, obj_name = self.split_path(path)
-        bucket = oss2.Bucket(self._auth, self._endpoint, bucket_name)
+        bucket = self._get_bucket(bucket_name)
         result = bucket.append_object(obj_name, location, value)
         return result.next_position
 
@@ -626,7 +634,7 @@ class OSSFileSystem(
         """
         headers = {"x-oss-range-behavior": "standard"}
         bucket_name, obj_name = self.split_path(path)
-        bucket = oss2.Bucket(self._auth, self._endpoint, bucket_name)
+        bucket = self._get_bucket(bucket_name)
         try:
             object_stream = bucket.get_object(
                 obj_name, byte_range=(start, end), headers=headers
@@ -654,6 +662,7 @@ class OSSFileSystem(
         if truncate or not self.exists(path):
             with self.open(path, "wb", **kwargs):
                 pass
+            self.invalidate_cache(self._parent(path))
 
     @dynamic_block_size
     def cat_file(self, path, start=None, end=None, **kwargs):
@@ -664,19 +673,19 @@ class OSSFileSystem(
     def pipe_file(self, path, value, **kwargs):
         """Set the bytes of given file"""
         bucket_name, obj_name = self.split_path(path)
-        bucket = oss2.Bucket(self._auth, self._endpoint, bucket_name)
+        bucket = self._get_bucket(bucket_name)
         bucket.put_object(obj_name, value, **kwargs)
+        self.invalidate_cache(self._parent(path))
 
-    def size(self, path):
-        """Size in bytes of file"""
-        bucket_name, obj_name = self.split_path(path)
-        if not obj_name:
-            return None
-        bucket = oss2.Bucket(self._auth, self._endpoint, bucket_name)
-        try:
-            return bucket.head_object(obj_name).content_length
-        except (oss2.exceptions.NoSuchBucket, oss2.exceptions.NoSuchKey):
-            return None
+    def invalidate_cache(self, path=None):
+        if path is None:
+            self.dircache.clear()
+        else:
+            path = self._strip_protocol(path)
+            self.dircache.pop(path, None)
+            while path:
+                self.dircache.pop(path, None)
+                path = self._parent(path)
 
 
 class OSSFile(AbstractBufferedFile):
